@@ -7,7 +7,7 @@ use HTML::TreeBuilder;
 use Carp qw( croak );
 
 use vars qw( $VERSION );
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 # web site data
 my $base = 'http://www.heavens-above.com/';
@@ -33,7 +33,7 @@ my %iso = (
     'AZ' => 'AJ',    # AZERBAIJAN
     'BB' => 'BB',    # BARBADOS
     'BD' => 'BG',    # BANGLADESH
-        'BE' => 'BE',    # BELGIUM
+    'BE' => 'BE',    # BELGIUM
     'BF' => 'UV',    # BURKINA FASO
     'BG' => 'BU',    # BULGARIA
     'BH' => 'BA',    # BAHRAIN
@@ -298,126 +298,6 @@ sub _isolatin {
                {aaaaaaaaaaaacceeeeeeeeiiiiiiiiddnnoooooooooooouuuuuuuuyyy};
 }
 
-=pod
-
-=head1 NAME
-
-WWW::Gazetteer::HeavensAbove - Find location of world towns and cities
-
-=head1 SYNOPSIS
-
- use WWW::Gazetteer::HeavensAbove;
-
- my $atlas = WWW::Gazetteer::HeavensAbove->new;
-
- # simple query using ISO 3166 codes
- my @towns = $atlas->find( 'Bacton', 'GB' );
- print $_->{name}, ", ", $_->{elevation}, $/ for @towns;
-
- # simple query using heavens-above.com codes
- my @towns = $atlas->query( 'Bacton', 'UK' );
- print $_->{name}, ", ", $_->{elevation}, $/ for @towns;
-
- # big queries can use a callback (and return nothing)
- $atlas->find(
-     'Bacton', 'GB',
-     sub { print $_->{name}, ", ", $_->{elevation}, $/ for @_ }
- );
-
- # find() returns an arrayref in scalar context
- $cities = $atlas->find( 'Paris', 'FR' );
- print $cities->[1]{name};
-
- # the heavens-above.com site supports complicated queries
- my @az = $atlas->find( 'a*z', 'FR' );
-
- # and you can naturally use callbacks for those!
- my ($c, n);
- $atlas->find( 'N*', 'US', sub { $c++; $n += @_ }  );
- print "$c web requests needed for finding $n cities";
-
- # or use your own UserAgent
- my $ua = LWP::UserAgent->new;
- $atlas = WWW::Gazetteer::HeavensAbove->new( ua => $ua );
-
- # another way to create a new object
- use WWW::Gazetteer;
- my $g = WWW::Gazetteer->new('HeavensAbove');
-
-=head1 DESCRIPTION
-
-A gazetteer is a geographical dictionary (as at the back of an atlas).
-The WWW::Gazetteer::HeavensAbove module uses the information at
-http://www.heavens-above.com/countries.asp to return geographical location
-(longitude, latitude, elevation) for towns and cities in countries in the
-world.
-
-Once a WWW::Gazetteer::HeavensAbove objects is created, use the find()
-method to return lists of hashrefs holding all the information for the
-matching cities.
-
-A city tructure looks like this:
-
- $lesparis = {
-     iso        => 'FR',
-     latitude   => '45.633',
-     regionname => 'Region',
-     region     => 'Rhne-Alpes',
-     alias      => 'Les Paris',
-     elevation  => '508',            # meters
-     longitude  => '5.733',
-     name       => 'Paris',
- };
- 
-Note: the 'regioname' attribute is the local name of a region (this can
-change from country to country).
-
-Due to the way heavens-above.com's database was created, cities from the
-U.S.A. are handled as a special case. The C<region> field is the state,
-and a special field named C<county> holds the county name.
-
-Here is an example of an American city:
-
- $newyork = {
-     iso        => 'US',
-     latitude   => '39.685',
-     regionname => 'State',
-     region     => 'Missouri',
-     county     => 'Caldwell',    # this is only for US cities
-     alias      => '',
-     elevation  => '244',
-     longitude  => '-93.927',
-     name       => 'New York'
- };
- 
-=head2 Methods
-
-=over 4
-
-=item new()
-
-Return a new WWW::Gazetteer::UserAgent, ready to find() cities for you.
-
-The constructor can be given a list of parameters.
-Currently supported parameters are :
-
-C<ua> - the LWP::UserAgent used for the web requests
-
-C<retry> - the number of times a failed connection will be retried
-
-You can also use the generic WWW::Gazetteer module to create a new
-WWW::Gazetteer::HeavenAbove object:
-
- use WWW::Gazetteer;
- my $g = WWW::Gazetteer->new('HeavensAbove');
-
-You can also pass it inialisation parameters:
-
- use WWW::Gazetteer;
- my $g = WWW::Gazetteer->new('HeavensAbove',  retry => 3);
-
-=cut
-
 sub new {
     my $class = shift;
 
@@ -431,69 +311,15 @@ sub new {
     bless { ua => $ua, retry => 5, @_ }, $class;
 }
 
-=item find( $city, $country [, $callback ] )
-
-Return a list of cities matching $city, within the country with ISO 3166
-code $code (not all codes are supported by heavens-above.com).
-
-This method always returns an array of city structures. If the request
-returns a lot of cities, you can pass a callback routine to find().
-This routine receives the list of city structures as @_. If a callback
-method is given to find(), find() will return an empty list.
-
-A single call to find() can lead to several web requests. If the
-query returns more than 200 answeris, heavens-above.com cuts at 200.
-WWW::Gazetteer::HeavensAbove picks as many data as possible from this
-first answer and then refines the query again and again.
-
-Here's an excerpt from heavens-above.com documentation: 
-
-=over 4
-
-You can use "wildcard" characters to match several towns if you're not
-sure of the exact name. These characters are '*' which means "match
-any sequence of characters", and '?' which means "match any single
-character". The search is not case-sensitive.
-
-Diacritic characters, such as  and  can either be entered directly
-from the keyboard (assuming you have the appropriate keyboard), or
-simply enter the letter without diacritic (e.g. you can enter 'a' for
-'', '', '', '', '' and ''). If you need a special character which
-is not on your keyboard, and is not a diacritic (e.g. the german '',
-and scandinavian ''), simply enter a "?" instead, and all characers
-will be matched.
-
-=back
-
-Note: heavens-above.com doesn't use ISO 3166 codes, but its own
-country codes. If you want to use those directly, please see the query()
-method. (And read the source for the full list of HA codes.)
-
-=cut
-
 sub find {
     my ( $self, $query, $iso ) = ( shift, shift, uc shift );
     croak "No HA code for $iso ISO code" if !exists $iso{$iso};
     return $self->query( $query, $iso{$iso}, @_ );
 }
 
-=item fetch( $searchstring, $code [, $callback ] );
-
-fetch() is a synonym for find(). It is kept for backward compatibility.
-
-=cut
-
+# alias for backward compatibility
 *WWW::Gazetteer::HeavensAbove::fetch = \&find;
 
-=item query( $searchstring, $code [, $callback ] );
-
-This method is the actual method called by find().
-
-The only difference is that $code is the heavens-above.com specific
-country code, instead of the ISO 3166 code.
-
-=cut
-
 sub query {
     my ( $self, $query, $code, $callback ) = @_;
     $code = uc $code;
@@ -644,16 +470,185 @@ sub _getpage {
     return ( $string, @data );
 }
 
+1;
+
+__END__
+
+=head1 NAME
+
+WWW::Gazetteer::HeavensAbove - Find location of world towns and cities
+
+=head1 SYNOPSIS
+
+ use WWW::Gazetteer::HeavensAbove;
+
+ my $atlas = WWW::Gazetteer::HeavensAbove->new;
+
+ # simple query using ISO 3166 codes
+ my @towns = $atlas->find( 'Bacton', 'GB' );
+ print $_->{name}, ", ", $_->{elevation}, $/ for @towns;
+
+ # simple query using heavens-above.com codes
+ my @towns = $atlas->query( 'Bacton', 'UK' );
+ print $_->{name}, ", ", $_->{elevation}, $/ for @towns;
+
+ # big queries can use a callback (and return nothing)
+ $atlas->find(
+     'Bacton', 'GB',
+     sub { print $_->{name}, ", ", $_->{elevation}, $/ for @_ }
+ );
+
+ # find() returns an arrayref in scalar context
+ $cities = $atlas->find( 'Paris', 'FR' );
+ print $cities->[1]{name};
+
+ # the heavens-above.com site supports complicated queries
+ my @az = $atlas->find( 'a*z', 'FR' );
+
+ # and you can naturally use callbacks for those!
+ my ($c, n);
+ $atlas->find( 'N*', 'US', sub { $c++; $n += @_ }  );
+ print "$c web requests needed for finding $n cities";
+
+ # or use your own UserAgent
+ my $ua = LWP::UserAgent->new;
+ $atlas = WWW::Gazetteer::HeavensAbove->new( ua => $ua );
+
+ # another way to create a new object
+ use WWW::Gazetteer;
+ my $g = WWW::Gazetteer->new('HeavensAbove');
+
+=head1 DESCRIPTION
+
+A gazetteer is a geographical dictionary (as at the back of an atlas).
+The C<WWW::Gazetteer::HeavensAbove> module uses the information at
+L<http://www.heavens-above.com/countries.asp> to return geographical location
+(longitude, latitude, elevation) for towns and cities in countries in the
+world.
+
+Once a C<WWW::Gazetteer::HeavensAbove> objects is created, use the C<find()>
+method to return lists of hashrefs holding all the information for the
+matching cities.
+
+A city tructure looks like this:
+
+ $lesparis = {
+     iso        => 'FR',
+     latitude   => '45.633',
+     regionname => 'Region',
+     region     => 'Rhne-Alpes',
+     alias      => 'Les Paris',
+     elevation  => '508',            # meters
+     longitude  => '5.733',
+     name       => 'Paris',
+ };
+ 
+Note: the 'regioname' attribute is the local name of a region (this can
+change from country to country).
+
+Due to the way heavens-above.com's database was created, cities from the
+U.S.A. are handled as a special case. The C<region> field is the state,
+and a special field named C<county> holds the county name.
+
+Here is an example of an American city:
+
+ $newyork = {
+     iso        => 'US',
+     latitude   => '39.685',
+     regionname => 'State',
+     region     => 'Missouri',
+     county     => 'Caldwell',    # this is only for US cities
+     alias      => '',
+     elevation  => '244',
+     longitude  => '-93.927',
+     name       => 'New York'
+ };
+ 
+=head2 Methods
+
+=over 4
+
+=item new()
+
+Return a new C<WWW::Gazetteer::UserAgent>, ready to C<find()> cities for you.
+
+The constructor can be given a list of parameters.
+Currently supported parameters are:
+
+C<ua> - the C<LWP::UserAgent> used for the web requests
+
+C<retry> - the number of times a failed connection will be retried
+
+You can also use the generic C<WWW::Gazetteer> module to create a new
+C<WWW::Gazetteer::HeavenAbove> object:
+
+ use WWW::Gazetteer;
+ my $g = WWW::Gazetteer->new('HeavensAbove');
+
+You can also pass it inialisation parameters:
+
+ use WWW::Gazetteer;
+ my $g = WWW::Gazetteer->new('HeavensAbove',  retry => 3);
+
+=item find( $city, $country [, $callback ] )
+
+Return a list of cities matching C<$city>, within the country with ISO 3166
+code $code (not all codes are supported by heavens-above.com).
+
+This method always returns an array of city structures. If the request
+returns a lot of cities, you can pass a callback routine to C<find()>.
+This routine receives the list of city structures as @_. If a callback
+method is given to C<find()>, C<find()> will return an empty list.
+
+A single call to C<find()> can lead to several web requests. If the
+query returns more than 200 answeris, heavens-above.com cuts at 200.
+C<WWW::Gazetteer::HeavensAbove> picks as many data as possible from this
+first answer and then refines the query again and again.
+
+Here's an excerpt from heavens-above.com documentation: 
+
+=over 4
+
+You can use "wildcard" characters to match several towns if you're not
+sure of the exact name. These characters are '*' which means "match
+any sequence of characters", and '?' which means "match any single
+character". The search is not case-sensitive.
+
+Diacritic characters, such as  and  can either be entered directly
+from the keyboard (assuming you have the appropriate keyboard), or
+simply enter the letter without diacritic (e.g. you can enter 'a' for
+'', '', '', '', '' and ''). If you need a special character which
+is not on your keyboard, and is not a diacritic (e.g. the german '',
+and scandinavian ''), simply enter a "?" instead, and all characers
+will be matched.
+
+=back
+
+Note: heavens-above.com doesn't use ISO 3166 codes, but its own
+country codes. If you want to use those directly, please see the C<query()>
+method. (And read the source for the full list of HA codes.)
+
+=item fetch( $searchstring, $code [, $callback ] );
+
+fetch() is a synonym for find(). It is kept for backward compatibility.
+
+=item query( $searchstring, $code [, $callback ] );
+
+This method is the actual method called by find().
+
+The only difference is that $code is the heavens-above.com specific
+country code, instead of the ISO 3166 code.
+
 =back
 
 =head2 Callbacks
 
-The find() and query() methods both accept a optionnal coderef as
+The C<find()> and C<query()> methods both accept a optionnal coderef as
 their third argument. This method is used as a callback each time a
 batch of cities is returned by a web query to heavens-above.com.
 
 This can be very useful if a query with a joker returns more than
-200 answers.  WWW::Gazetteer::HeavensAbove breaks it into new requests
+200 answers.  C<WWW::Gazetteer::HeavensAbove> breaks it into new requests
 that return a smaller number of answers. The callback is called with
 the results of the subquery after each web request.
 
@@ -670,13 +665,13 @@ An example callback is (from F<eg/city.pl>):
  };
 
 Please note that, due to the nature of the queries, your callback
-can (and will most probably) be called with an empty @_.
+can (and will most probably) be called with an empty C<@_>.
 
 =head1 ALGORITHM
 
 The web site returns only the first 200 answers to any query.
 To handle huge requests like '*' (the biggest possible),
-WWW::Gazetteer::HeavensAbove splits the requests in several parts.
+C<WWW::Gazetteer::HeavensAbove> splits the requests in several parts.
 
 Example, looking for C<pa*> in France:
 
@@ -725,21 +720,21 @@ start again.
 
 Bugs in the database are not from heavens-above.com, since they
 "put together and enhanced" data from the following two sources:
-US Geological Survey (http://geonames.usgs.gov/index.html) for the
+US Geological Survey (L<http://geonames.usgs.gov/index.html>) for the
 USA and dependencies, and The National Imaging and Mapping Agency
-(http://www.nima.mil/gns/html/index.html) for all other countries.
+(L<http://www.nima.mil/gns/html/index.html>) for all other countries.
 
-See also: http://www.heavens-above.com/ShowFAQ.asp?FAQID=100
+See also: L<http://www.heavens-above.com/ShowFAQ.asp?FAQID=100>
 
 =head1 AUTHOR
 
-Philippe "BooK" Bruhat E<lt>book@cpan.orgE<gt>.
+Philippe "BooK" Bruhat C<< <book@cpan.org> >>.
 
 This module was a script, before I found out about Leon Brocard's
-WWW::Gazetteer module. Thanks! And, erm, bits of the documentation were
-stolen from WWW::Gazetteer.
+L<WWW::Gazetteer module>. Thanks! And, erm, bits of the documentation were
+stolen from L<WWW::Gazetteer>.
 
-Thanks to Alain Zalmanski (of http://www.fatrazie.com/ fame) for asking
+Thanks to Alain Zalmanski (of L<http://www.fatrazie.com/> fame) for asking
 me for all that geographical data in the first place.
 
 =head1 SEE ALSO
@@ -747,17 +742,17 @@ me for all that geographical data in the first place.
 "How I captured thousands of Afghan cities in a few hours", one of my
 lightning talks at YAPC::Europe 2002 (Munich). You had to be there.
 
-WWW::Gazetteer and WWW::Gazetteer::Calle, by Leon Brocard.
+L<WWW::Gazetteer> and L<WWW::Gazetteer::Calle>, by Leon Brocard.
 
 The use Perl discussion that had me write this module from the original
-script: http://use.perl.org/~acme/journal/8079
+script: L<http://use.perl.org/~acme/journal/8079>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2002-2006 Philippe Bruhat.
 
 This module is free software; you can redistribute it or modify it under
 the same terms as Perl itself.
 
 =cut
 
-1;
-
